pub struct ImportableExecutionAlgorithmConfig {
pub exec_algorithm_path: String,
pub config_path: String,
pub config: HashMap<String, Value>,
}Expand description
Configuration for creating execution algorithms from importable paths.
Fields
exec_algorithm_path: StringThe fully qualified name of the execution algorithm class.
config_path: StringThe fully qualified name of the execution algorithm config class.
config: HashMap<String, Value>The execution algorithm configuration as a dictionary.